/*
* Program that connects to WiFi without password (or WEP) on defined port
* Create socket connection with defined Java program: Listener.java(.jar)
* Enable DigitalPins as INPUT_PULLUP for sensors (open,close)
* Send to connected server the status of sensors
* Alarm mode (on, off), alarm signal if mode=on, sensors opens
* 
* Author: Kevin Sedevcic
*/

#include <MWiFi.h>             // include library

/********* Definitions (adapt to your environment) **********************/

#define ACCESSPOINT  "KaneFuryNet"       // access point name
#define PASSWORD     ""                  // password if WAP
#define REMOTEIP     "192.168.0.148"     // serv address
#define PORT         4161              // application port

#define TIMEINT      10                  // time interval (ms)
#define D4            4                  // input (pullup) pin D4
#define D8            8                  // input (pullup) pin D8
#define DLed          9                  // Led output pin D1
/*************************************************************************/

char ip[16];                   // buffer for local ip address
int fc=0;                      // flag connection
boolean fs=0;                  // flag socket open
int csocket;                   // client socket handle

int an1 = 123;                      // test values
int an2 = 2344;
int d1 = 1111;
int d2 = 0612;



MWiFi WIFI;                    //instance of MWiFi library

void setup() 
{
  Serial.begin(9600);
  pinMode(D4,INPUT_PULLUP);
  pinMode(D8,INPUT_PULLUP);
  pinMode(DLed,OUTPUT);
  
  WIFI.begin();                // startup wifi shield
  
  WIFI.setNetMask("255.255.255.0");  //modify default
  WIFI.setGateway("192.168.0.1");        //modify default
  
  if (PASSWORD==""){WIFI.ConnSetOpen(ACCESSPOINT);}         // if passw= empty string connect in open mode
  else             {WIFI.ConnSetWPA(ACCESSPOINT,PASSWORD);} // else connect in WAP mode
  
  netConnection();                   // connection to access point   
 
  if (fc==1)  socketConnection();        // if connect to access point try to open socket
  //end of startup 
} 

void netConnection()
{
    int i;for(i=0;i<5;i++) {fc=WIFI.Connect(); if(fc) break;}             // try to connect for 5 times
    if (!fc)     {delay(10000);wdt_enable(WDTO_1S);}                      // reset if no connection 
    WIFI.getIP(ip);                                                       // get dynamic ip
    Serial.println("Net connected!");
}

void socketConnection()
{
    Serial.print("Start socket connection to ");Serial.print(REMOTEIP);
    Serial.print(":");Serial.println(PORT);
    csocket=WIFI.openSockTCP(REMOTEIP,PORT);                             // try to connect to remote ip 
    if (csocket==255)
     {fs=false;Serial.println("Socket not available!");return;}              // socket not valid. No link! 
    else 
     {fs=true;Serial.println("Socket connected!");}                         // flag socket link open
}
  
char rec[40];                                     // buffer for sending record 
  
void loop() 
{
  if(fs)                                          // if socket connected
  {
   
    int d4=digitalRead(D4);
    int d8=digitalRead(D8);
   
   
   //   digitalWrite(DLed, HIGH);       // turn off DLed d1
    
  
        
    if(d4 == 1 | d8 == 1){
      digitalWrite(DLed, HIGH);       // turn on pullup resistors
    }else{
      digitalWrite(DLed, LOW);       // turn on pullup resistors
    }
/*
    int an1=analogRead(AN1);                      // read values
    int an2=analogRead(AN2);
    */
    
    sprintf(rec,"%d %d ",d4,d8);      // prepare record coding values to string
    int nb=WIFI.writeDataLn(csocket,rec);                // send record
    Serial.println(rec);
    nb=WIFI.writeDataLn(csocket,rec);
    Serial.println(rec);
    an1=an1+1;

}else socketConnection();                        // if socket not yet open try to open
 
  delay(TIMEINT*150); 
 
}


